package prescript


#######################################################################
# java images/scripts
#######################################################################

# the _javalinks_ macros are the flashy image links at the top right of
# the page. 

_javalinks_ {_imagehome_}
_javalinks_ [v=1] {
_imagehome_<br>
}


#######################################################################
# icons
#######################################################################

_iconhpscrpt_ {<img src="_httpiconhpscrpt_" width=_widthhpscrpt_ height=_heighthpscrpt_}

#######################################################################
# http macros 
#
# These contain the url without any quotes
#######################################################################

_httpiconhpscrpt_ {_httpimg_/h\_pscrpt.gif}
_widthhpscrpt_ {200}
_heighthpscrpt_ {57}


#######################################################################
# page content
#######################################################################

_pagetitle_ {NZDL: PreScript}

_imagethispage_ {_iconhpscrpt_}

_content_ {
_iconblankbar_
<p>
<i>PreScript</i> is a utility for extracting text from PostScfript files.
PreScript offers:

<dl>
<dt><b>PostScript conversion to plain ASCII or HTML.</b></dt>

<dd><i>PreScript</i> is really a PostScript to plain text converter,
but rudimentary HTML can also be produced.  Tags are inserted to mark
paragraphs (&lt;p&gt;), short lines (&lt;br&gt;), page breaks
(&lt;hr&gt;), and header and footers (italisized with
&lt;i&gt;...&lt;/i&gt;).

<dt><b>Paragraph boundaries detection.</b></dt>
<dd><i>PreScript</i> determines the line spacing of a document and
uses this (and also indentations) to determine paragraph boundaries. 

<dt><b>Hyphenation removal.</b></dt>
<dd>Hyphenated words are de-hyphenated.

<dt><b>Ligature translation.</b></dt>
<dd>Most ligatures used by TeX document are detected.
<i>PreScript</i> doesn't track font changes making it impossible to
reliablely detect all ligatures.

</dl>
<br>
<h3>Installing PreScript</h3>
<i>PreScript</i> is written in PostScript and Python.  You will
need <a href="http://www.cs.wisc.edu/~ghost">Ghostscript</a> (at least
version 4.01) and the
<a href="http://www.python.org">Python</a> interpreter (at least
version 1.4.).

<h4>The PreScript 0.1 distribution</h4>

This distribution is the most stable - it is what you should use to
do real work.

<ul>

<li>Download the <a href="http://www.nzdl.org/download/prescript/prescript-0.1.tar.gz">PreScript
0.1</a> distribution.

<li>Define the environment variable <tt>PRESCRIPT_DIR</tt> to the
directory where <i>PreScript</i> is installed (or where ever you put
<tt>prescript.ps</tt>).

<li>Move <tt>prescript.py</tt> to a directory listed in your
<tt>PATH</tt> environment variable.  You may want to remove the
<tt>.py</tt> suffix (<tt>prescript.py</tt> can be either a standalone
program, or an imported library of another Python program).

<li>Change <tt>\#! /usr/local/bin/python</tt> in
<tt>prescript.py</tt> to the location of your Python interpreter.

</ul>

<h4>The PreScript 2 distribution</h4>

This is a beta release of our latest version. This version is a lot cleaner and
faster; it is also extensible (users can write their own renderers), 
better documented, and contains better prediction of line, paragraph, 
and page breaks. If you notice any bugs, want to request new
features, or want to become a beta tester please email the <a
href="mailto:nzdl@cs.waikato.ac.nz">New Zealand Digital Library
administrator</a>.

<ul>

<li>Download a <i>PreScript 2</i> distribution (the later versions are more stable).

<blockquote>
<a href="http://www.nzdl.org/download/prescript/prescript-2.0.tar.gz">PreScript 2.0</a><br>
<a href="http://www.nzdl.org/download/prescript/prescript-2.1.tar.gz">PreScript 2.1</a><br>
<a href="http://www.nzdl.org/download/prescript/prescript-2.2.tar.gz">PreScript 2.2</a> -- same as Prescript 2.1 but compatibility issues
with python 1.5 have been fixed
</blockquote>

<li>On unix systems 'make install' will install prescript to /usr/local/bin. It will
also install the accompanying manual page (to install somewhere else simply edit
the Makefile).

<li>If not installing with the make utility:<br>
It is easiest if all of the program scripts are kept in the same directory,
which ideally should be listed in the <tt>PATH</tt> environment variable.  If
this is inconvenient, be sure that <tt>PRESCRIPT_DIR</tt> points to where
<tt>prescript.ps</tt> is installed, and that <tt>PYTHONPATH</tt> points to
where <tt>*.py</tt> are installed.

<li>Change <tt>\#!/usr/local/bin/python</tt> in <tt>prescript</tt> to the
location of your Python interpreter ('make install' does NOT do this for you).

</ul>
<br>

<h3>Running PreScript</h3>
<b>Usage:</b>
<blockquote>
prescript <i>format</i> <i>input</i> [<i>output</i>]
</blockquote>

<ul>
<li><i>format</i> is either <tt>plain</tt> or <tt>html</tt>.
<li><i>input</i> is the input filename, a PostScript file.
<li><i>output</i> is the output filename.  By default, the output file
name is the same as the input filename with the path removed and suffix
replace to either <tt>.txt</tt> or <tt>.html</tt>.
</ul>

<br>
<h3>Bugs</h3>
Please report bugs to the <a
href="mailto:nzdl@cs.waikato.ac.nz">New Zealand Digital Library
administrator</a>.
<p><br>

<h3>Notes</h3>
<i>PreScript</i> is a port of a Perl program used by the New Zealand Digital
Library project to convert computer science technical reports to HTML.  The
Perl version is deemed unfit for a public release because the code is quite
messy (a consequence of Perl's cumbersome syntax for defining objects).  The
Python version is considerably easier to understand, maintain, and extend.  
The technical paper <a
href="http://www.nzdl.org/download/prescript/prescript.ps.gz">prescript.ps.gz</a> documents the
algorithms and heuristics used in <i>PreScript 0.1</i> - there is an
update to this for <i>PreScript 2</i> inside its distribution 
archive.<p><br>

<h3>Other Postscript Converters</h3>
Here is a summary of other PostScript to text converters we found.

<dl>
<dt><a
href="http://www.research.digital.com/SRC/virtualpaper/pstotext.html"><b>pstotext</b></a></dt>


<dd>From the DEC Virtual Paper research project.  PostScript program
and C program.  Probably the best PostScript to text converter (after
<i>PreScript</i>, of course).

<dt><a
href="http://stasi.bradley.edu/ftp/pub/ps2html/ps2html-v2.html"><b>ps2html,
The Sequel</b></a></dt>

<dd>Developed at John Hopkins University to convert JHU journal
articals to HTML.  This converter attempts to preserve the formatting
of the original PostScript document, but is tied to PostScript
files generated with a specific package (QuarkXPress?).  A table
describing a number of parameters is used to aid conversion and can be
modified for new formats.  Uses a variation of Ghostscript's
<tt>ps2ascii.ps</tt>.

<dt><b>ps2ascii.ps</b></dt>

<dd>Part of the Ghostscript distribution.  <tt>ps2ascii.ps</tt> is
considerably less robust than <i>PreScript</i>.

<dt><a
href="ftp://ftp.mpce.mq.edu.au/pub/comp/src/ps2a.sh"><b>ps2a.sh</b></a></dt>

<dd>A PostScript program similar to Ghostscript's <tt>ps2ascii.ps</tt>.

<dt><a href="ftp://apocalypse.engr.ucf.edu:/usr/ssd/ps2ascii.shar"><b>ps2ascii.shar</b></a></dt>

<dd>A PostScript program and Perl script.

<dt><a
href="ftp://wilma.cs.brown.edu/pub/postscript/ps2ascii.pl"><b>ps2ascii.pl</b></a></dt>

<dd>A Perl script that extracts parenthesized text from a PostScript
file.

<dt><a
href="ftp://ftp.funet.fi/pub/archive/alt.sources/volume92/Feb/920223.01.gz"><b>ps2txt</b></a></dt>

<dd>A stand alone C program that extracts parenthesized text.  Some
special code to deal with <tt>dvips</tt> generated files.

</dl>

}
